VideoQuality enum

Video quality presets (NEW v1.1.0)

Inheritance
Available extensions

Values

low → const VideoQuality
const VideoQuality(fps: 15, bitrate: 2000000, description: 'Low (15 FPS, 2 Mbps) - Smallest file')
medium → const VideoQuality
const VideoQuality(fps: 30, bitrate: 5000000, description: 'Medium (30 FPS, 5 Mbps) - Balanced')
high → const VideoQuality
const VideoQuality(fps: 60, bitrate: 10000000, description: 'High (60 FPS, 10 Mbps) - Best quality')

Properties

bitrate → int
final
description → String
final
fps → int
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<VideoQuality>
A constant List of the values in this enum, in order of their declaration.