TouchVisualizationConfig class

Configuration for touch visualization

Constructors

TouchVisualizationConfig({Color color = Colors.blue, double size = 50.0, double opacity = 0.6, bool showRipple = true, Duration rippleDuration = const Duration(milliseconds: 300)})
const

Properties

color Color
Color of the touch indicator
final
hashCode int
The hash code for this object.
no setterinherited
opacity double
Opacity of the touch indicator
final
rippleDuration Duration
Duration of the ripple animation
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showRipple bool
Show ripple effect on touch
final
size double
Size of the touch indicator
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited